<?php

namespace Drupal\omni_twig\TwigExtension;

use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Makes available debugging functions.
 */
class OmniTwigExtension extends AbstractExtension {

  /**
   * The entity_type.manager service.
   *
   * @var Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeManagerInterface $entity_manager) {
    $this->entityTypeManager = $entity_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return 'omni_twig.twig_extension';
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions() {
    return [
      new TwigFunction('dump', [$this, 'dump'], ['is_safe' => ['html']]),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFilters() {
    return [
      new TwigFunction('formatter', [$this, 'view'], ['is_safe' => ['html']]),
      new TwigFunction('view', [$this, 'view'], ['is_safe' => ['html']]),
    ];
  }

  /**
   * Renders a variable using var_dump.
   *
   * @param mixed $var
   *   The variable to dump.
   *
   * @return string
   *   Debug representation of the variable.
   */
  public function dump($var) {
    ob_start();
    var_dump($var);
    $ret = ob_get_contents();
    ob_end_clean();
    return $ret;
  }

  /**
   * Calls the formatter for the object.
   */
  public function view($obj, $formatter = 'default_formatter', $settings = []) {
    if (method_exists($obj, 'view')) {
      $options = [
        'label' => 'hidden',
        'type' => $formatter,
        'settings' => $settings,
      ];
      $ret = $obj->view($options);
      return $ret;
    }

    return '<pre>Formatter not available.</pre>';
  }

}

